%%Modelacion del sistema de barrar paralelas con elasticos

clc
clear all
close all


%Constantes:
L=0.300;
w_fijo=0.050;
b=0.010;
m=5;

x_d=sqrt(L^2-w_fijo^2); %para beta = 90
theta_min_r = (acos(x_d/L));
disp('Theta donde resorte es horizontal: ')
disp(rad2deg(theta_min_r))

%Variables
k_fijo=50;
k=k_fijo:50:k_fijo*10;

%x_0 = 0.060:0.020:0.250;
x_0 = [0.250 0.100];
x_0_fijo=0.20;

theta_lim = (asin(2*b/w_fijo));
disp('Theta donde topan las barras para w=5cm : ')
disp(rad2deg(pi/2-theta_lim))

%Variaciones de w para ver angulo de tope de barras:
w=0.030:0.005:0.08;

theta_lim_w = (asin(2*b./w));
figure
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
alldatacursors = findall(gcf,'type','hggroup')
set(alldatacursors,'FontSize',18)
plot(w.*100,rad2deg(theta_lim_w),'Linewidth',2)
%title('Distancia entre ejes v/s ngulo mximo estructura', 'FontSize', 16)
xlabel('Distance w [cm]', 'FontSize', 16)
ylabel('Limit angle [ ]', 'FontSize', 16)
print -depsc

theta=[theta_lim:0.001:pi-theta_lim];

%Largo del resorte
x=sqrt(L^2+2*L*w_fijo*cos(theta)+w_fijo^2);
figure
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
plot(rad2deg(theta), x.*100,'Linewidth',2)
%set(gca, 'Xdir', 'reverse')
%title('Estiramiento del resorte', 'FontSize', 16)
xlabel('Elevation angle \theta [ ]', 'FontSize', 16)
ylabel('Elastic band length x(\theta) [cm]', 'FontSize', 16)
print -depsc

%%

%Angulo del resorte respecto a vertical
beta = acos((-L^2+x.^2+w_fijo^2)./(2*w_fijo*x));

figure
set(gcf,'Color',[1,1,1])
plot(rad2deg(theta), rad2deg(beta),'Linewidth',2)
%set(gca, 'Xdir', 'reverse')
title('Relacin del angulo de la estructura y del resorte para w=5cm')
xlabel('ngulo de la estructura')
ylabel('ngulo del resorte ')


%Angulo del resorte y de la barra
alpha = acos((L^2+x.^2-w_fijo^2)./(2*L*x));
figure
set(gcf,'Color',[1,1,1])
plot(rad2deg(theta), rad2deg(alpha),'Linewidth',2)
%set(gca, 'Xdir', 'reverse')
title('Angulo del resorte respecto a la barra de torque')
xlabel('ngulo de la estructura')
ylabel('ngulo del resorte ')


torque_r = zeros(length(theta), length(k));
torque_m = zeros(length(theta));
N = size(torque_r,2);

figure
hold on
for i=1:N
    
    [ torque_r(:,i) , torque_m ,~] = torque_resorte( L,w_fijo,b,k(i),x_0_fijo,m ,theta);
    plot(rad2deg(theta),torque_r(:,i),'Color',[1,(N-i)/N,i/N],'Linewidth',2)
    legendInfo{i} = ['N_{e} = ' num2str(k(i)/k_fijo)]; %Numero de elasticos
    
end
%set(gca, 'Xdir', 'reverse')
set(gcf,'Color',[1,1,1])
xlabel('\theta [ ]')
%ylim([0 18])
ylabel('Torque [Nm]')
title('Variacin en cantidad de elsticos de k=50 para x0 = 20 cm')
plot(rad2deg(theta),torque_m,'-b','Linewidth',2)
legendInfo{i+1} = ['\tau_b_r_a_z_o']; %Numero de elasticos
legend(legendInfo,'Location','northeastoutside')
box on
hold off


%%
% Caso de variacin de x_0 para k=250 -> 5 elasticos
% CASO DOBLE ANALISIS

torque_r_x = zeros(length(theta), length(x_0));
N = size(torque_r_x,2);

figure
%subplot(1,2,1)
hold on
for i=1:N
    
    [ torque_r_x(:,i) , torque_m ,~] = torque_resorte( L,w_fijo,b,k_fijo*10,x_0(i),m ,theta);
    plot(rad2deg(theta),torque_r_x(:,i),'Color',[(N-i)/N,0,i/N],'Linewidth',2)
    %legendInfo{i} = ['N_e=5, x_0=' num2str(x_0(i)*100) 'cm'];
    legendInfo{i} = ['\tau_e_' num2str(i)];
    
end

for i=1:N
    
    [ torque_r_x(:,i) , torque_m ,~] = torque_resorte( L,w_fijo,b,k_fijo*20,x_0(i),m ,theta);
    plot(rad2deg(theta),torque_r_x(:,i),'Color',[i/N,1,(N-i)/N],'Linewidth',2)
    %legendInfo{N+i} = ['N_e=10, x_0=' num2str(x_0(i)*100) ' cm']; ; %Numero de elasticos
    legendInfo{N+i} = ['\tau_e_' num2str(N+i)];  %Numero de elasticos
    
end

%set(gca, 'Xdir', 'reverse')
set(gcf,'Color',[1,1,1])
set(gca,'xtick',[])
set(gca,'ytick',[])
set(gca,'FontSize',14)
xlabel('\theta [ ]')
%ylim([0 18])
ylabel('\tau [Nm]')
%title('Variacin de x0 con k fijo, 5 elsticos')
plot(rad2deg(theta),torque_m,'-r','Linewidth',2)
legendInfo{2*N+1} = ['\tau_g'];
legend(legendInfo,'Location','northeast')
box on
hold off
print -depsc
%

% figure
% %subplot(1,2,2)
% hold on
% for i=1:N
%
% [ torque_r_x(:,i) , torque_m ,x_r,~] = torque_resorte( L,w_fijo,b,k_fijo*5,x_0(i),m);
% resorte = x_r./x_0(i);
% plot(rad2deg(theta),resorte,'Color',[1,(N-i)/N,i/N],'Linewidth',2)
% legendInfo{i} = ['x_0 = ' num2str(x_0(i)*100) ' cm']; ;
%
% end
% %set(gca, 'Xdir', 'reverse')
% set(gcf,'Color',[1,1,1])
% xlabel('\theta [ ]')
% %ylim([0 18])
% ylabel('x/x_0')
% title('Proporcin de estiramiento a largo natural')
% %plot(rad2deg(theta),torque_m,'-b','Linewidth',2)
% %legendInfo{i+1} = ['Torque brazo']; %Numero de elasticos
% %legend(legendInfo,'Location','northeast')
%
% box on
% hold off



%% Caso de variacin de x_0 para k=500 -> 10 elasticos

% torque_r_x = zeros(length(theta), length(x_0));
% figure
% hold on
% for i=1:N
%
% [ torque_r_x(:,i) , torque_m ,~] = torque_resorte( L,w_fijo,b,k_fijo*10,x_0(i),m ,theta);
% plot(rad2deg(theta),torque_r_x(:,i),'Color',[1,(N-i)/N,i/N],'Linewidth',2)
% legendInfo{i} = ['x_0 = ' num2str(x_0(i)*100) ' cm']; ; %Numero de elasticos
%
% end
% %set(gca, 'Xdir', 'reverse')
% set(gcf,'Color',[1,1,1])
% xlabel('\theta [ ]')
% %ylim([0 18])
% ylabel('Torque [Nm]')
% title('Variacin de x0 para k fijo, 10 elsticos')
% plot(rad2deg(theta),torque_m,'-b','Linewidth',2)
% legendInfo{i+1} = ['\tau_b_r_a_z_o']; %Numero de elasticos
% legend(legendInfo,'Location','northeastoutside')
% box on
% hold off
%
%
% figure
% %subplot(1,2,2)
% hold on
% for i=1:N
%
% [ torque_r_x(:,i) , torque_m ,x_r,~] = torque_resorte( L,w_fijo,b,k_fijo*10,x_0(i),m,theta);
% resorte = x_r./x_0(i);
% plot(rad2deg(theta),resorte,'Color',[1,(N-i)/N,i/N],'Linewidth',2)
% legendInfo{i} = ['x_0 = ' num2str(x_0(i)*100) ' cm']; ;
%
% end
% %set(gca, 'Xdir', 'reverse')
% set(gcf,'Color',[1,1,1])
% xlabel('\theta [ ]')
% %ylim([0 18])
% ylabel('x/x_0')
% title('Proporcin de estiramiento a largo natural')
% %plot(rad2deg(theta),torque_m,'-b','Linewidth',2)
% %legendInfo{i+1} = ['Torque brazo']; %Numero de elasticos
% %legend(legendInfo,'Location','northeast')
%
% box on
% hold off

%% Simulacion mas real...

%Variables
k_fijo=20; %elastico de escritorio
k=27*k_fijo:20:k_fijo*32;

%x_0 = 0.060:0.020:0.250;
x_0 = [0.250 0.100];
x_0_fijo=0.05;

theta=[theta_lim:0.001:pi-theta_lim];

torque_r = zeros(length(theta), length(k));
torque_m = zeros(length(theta));
N = size(torque_r,2);

figure,
hold on
for i=1:N
    
    [ torque_r(:,i) , torque_m ,~] = torque_resorte( L,w_fijo,b,k(i),x_0_fijo,m ,theta);
    plot(rad2deg(theta),torque_r(:,i),'Color',[1,(N-i)/N,i/N],'Linewidth',2)
    legendInfo{i} = ['\tau_e , n_{e} = ' num2str(k(i)/k_fijo)]; %Numero de elasticos
    
end
%set(gca, 'Xdir', 'reverse')
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
xlabel('Elevation Angle \theta [ ]','FontSize', 18)
%ylim([0 18])
ylabel('Torque [Nm]','FontSize', 18)
%title('Variacin en cantidad de elsticos de k=20 para x0 = 5 cm','FontSize', 18)
plot(rad2deg(theta),torque_m,'-b','Linewidth',2)
legendInfo{i+1} = ['\tau_g']; %Numero de elasticos
legend(legendInfo,'Location','northeast','FontSize', 10)
box on
hold off
print -depsc



%% Hagamos un grafico para demostrar la eleccion del motor dado un
% caso de estudio


torque_r = zeros(length(theta));
torque_m = zeros(length(theta));
k_fijo = 29*20;

%El motor tiene 40 kg-cm en el mejor caso
T_motor = ones(size(theta))*(40/10.197);

[ torque_e, torque_m ,~] = torque_resorte( L,w_fijo,b,k_fijo,x_0_fijo,m ,theta);

figure
hold on
plot(rad2deg(theta),torque_e,'-b','Linewidth',2)
%set(gca, 'Xdir', 'reverse')
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
xlabel('\theta [ ]','FontSize', 16)
%ylim([0 18])
ylabel('Torque [Nm]','FontSize', 16)
%title('Variacin en cantidad de elsticos de k=50 para x0 = 20 cm')
plot(rad2deg(theta),torque_m,'-r','Linewidth',2)
plot(rad2deg(theta),T_motor,'-g','Linewidth',2)
%legendInfo{i+1} = ['\tau_b_r_a_z_o']; %Numero de elasticos
legendInfo = ['\tau_e';'\tau_g';'\tau_m'];
legend(legendInfo,'Location','northeast')
xlim([20 160])
box on
hold off
print -depsc

figure
hold on
plot(rad2deg(theta),(torque_m-torque_e),'-c','Linewidth',2)
plot(rad2deg(theta),T_motor,'-g','Linewidth',2)
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
xlabel('\theta [ ]','FontSize', 16)
ylabel('Torque [Nm]','FontSize', 16)
legendInfo = ['Net Torque  ';'Servo Torque'];
legend(legendInfo,'Location','northeast')
ylim([-0.5 5])
xlim([20 160])
box on
hold off
print -depsc

%%
figure
hold on
plot(rad2deg(theta),(torque_m-torque_e),'-b','Linewidth',2)
%plot(rad2deg(theta),T_motor,'-g','Linewidth',2)
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
xlabel('\theta [ ]','FontSize', 16)
ylabel('Torque [Nm]','FontSize', 16)
legendInfo = ['Net Torque  '];%;'Servo Torque'];
legend(legendInfo,'Location','best')
%ylim([-0.5 5])
xlim([20 160])
box on
hold off
print -depsc

%%

figure
hold on
plot(rad2deg(theta),10.197*(torque_m-torque_e),'-b','Linewidth',2)
%plot(rad2deg(theta),T_motor,'-g','Linewidth',2)
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',14)
xlabel('\theta [ ]','FontSize', 16)
ylabel('Torque [kg-cm]','FontSize', 16)
legendInfo = ['Net Torque  '];%;'Servo Torque'];
legend(legendInfo,'Location','best')
%ylim([-0.5 5])
xlim([20 160])
box on
hold off
print -depsc

